@@ -6,12 +6,12 @@ use stm32f1xx_hal_bxcan::pac::ITM;
 #[macro_export]
 macro_rules! log_debug {
     ($logger:expr, $fmt:expr) => {
-        free(|cs| => {
+        free(|cs| {
             $logger.borrow(cs).log_debug($fmt);
         });
     };
     ($logger:expr, $fmt:expr, $($arg:tt)*) => {
-        free(|cs| => {
+        free(|cs| {
             $logger.borrow(cs).log_debug(&format!($fmt, $($arg)*));
         });
     };
@@ -20,12 +20,12 @@ macro_rules! log_debug {
 #[macro_export]
 macro_rules! log_warning {
     ($logger:expr, $fmt:expr) => {
-        free(|cs| => {
+        free(|cs| {
             $logger.borrow(cs).log_warning($fmt);
         });
     };
     ($logger:expr, $fmt:expr, $($arg:tt)*) => {
-        free(|cs| => {
+        free(|cs| {
             $logger.borrow(cs).log_warning(&format!($fmt, $($arg)*));
         });
     };
@@ -34,12 +34,12 @@ macro_rules! log_warning {
 #[macro_export]
 macro_rules! log_error {
     ($logger:expr, $fmt:expr) => {
-        free(|cs| => {
+        free(|cs| {
             $logger.borrow(cs).log_error($fmt);
         });
     };
     ($logger:expr, $fmt:expr, $($arg:tt)*) => {
-        free(|cs| => {
+        free(|cs| {
             $logger.borrow(cs).log_error(&format!($fmt, $($arg)*));
         });
     };
